@@ -1,4 +1,4 @@
-def attention(string):
+def attention(string:str):
     ret = f"""
     #############################
     !!!!!!!
@@ -20,4 +20,12 @@ hello = """
                 # #  ###  ##  ##  ###    # #  ###  ##  ##  ###
 ################################################################################
 ################################################################################
-"""
\ No newline at end of file
+"""
+
+def get_line(number_of_dots, replicable_value = "-",first_line=False):
+    line = f'\n+{replicable_value*number_of_dots}\n'
+    if first_line:
+        return line[1:]
+    return line
+
+line = get_line(51)
\ No newline at end of file
